accounts = [
    {'consumer_key': 'YT0tutGIiNJPN1qgeTbeycyZN',
     'consumer_secret': '3kr7n4wcpSKbJMg2HdUYuv7z6u8Jx5hYeaxEeDunEs94FxRpQI',
     'access_key': '954798157-kSCkePC2Nh6c7XNTDpGBrRW602EG2AAGlxBO742z',
     'access_secret': 'LSDcRb7uMlkzDfmwXlzY7puddMfdBfU8te5cWgbb4S7Rv'},

    {'consumer_key': 'jtsyzmLZh8PVeDFpDESNFhbfx',
     'consumer_secret': 'yf8qgkfrgOnqsLpOgIYRRjXNkWZ9RMSIvizW0MyfdcaWF73GVo',
     'access_key': '4175032576-IEdW79v1rKvaOgySkwlv6px4o7UFYshwACzdaKw',
     'access_secret': 'm6Fs8MzOflylebJoC82Zp8PsO7gAYhJ5TB9OYDULRHdih'},

    {'consumer_key': 'b4cbNQ34QnKrWZisexzevVQ7v',
     'consumer_secret': 'gFvkcmVUgt6BMWgx3MgdMgjuXa1ZAWceR00retenOVowJB2PVz',
     'access_key': '3965724493-Uxnvo0YX9XoqAmaD2L25iO4jgrlzldJas5GPMXM',
     'access_secret': 'GoRdhfiXsEuErQ6ktGDrmXm9x22EdootO9trET9MEUQtG'},
]